@@ -38,7 +38,14 @@ async def check_mc_player_available(main: Mcdbot, user: Union[Member, User], pla
 
 def check_mc_player_name_correctness(player: str):
     player = player.replace('_', 'Q')
-    if len(player) < 3 or len(player) > 16 or not (player.isalnum() and player.isascii() and ' ' not in player):
+
+    # str.isascii() is available only python 3.7+
+    try:
+        player.encode("ascii")
+    except UnicodeEncodeError:
+        raise BadMcPlayerError
+
+    if len(player) < 3 or len(player) > 16 or not (player.isalnum() and ' ' not in player):
         raise BadMcPlayerError
 
 
