@@ -42,9 +42,10 @@ class Redis(object):
                 self.started = True
 
     async def stop(self):
-        self.started = False
-        self._redis.close()
-        await self._redis.wait_closed()
+        if self.started:
+            self.started = False
+            self._redis.close()
+            await self._redis.wait_closed()
 
     # DB KEYS DEFINITION ###
     @staticmethod
